pub struct ConnectionManager { /* private fields */ }Implementations
Sourceimpl ConnectionManager
impl ConnectionManager
pub fn new( p2p_adaptor: Arc<Adaptor>, outbound_target: usize, inbound_limit: usize, dns_seeders: &'static [&'static str], default_port: u16, address_manager: Arc<ParkingLotMutex<AddressManager>>, ) -> Arc<Self>
pub async fn add_connection_request( &self, address: SocketAddr, is_permanent: bool, )
pub async fn stop(&self)
Sourcepub async fn ban(&self, ip: IpAddr)
pub async fn ban(&self, ip: IpAddr)
Bans the given IP and disconnects from all the peers with that IP.
GO-KASPAD: BanByIP
Sourcepub async fn is_banned(&self, address: &SocketAddr) -> bool
pub async fn is_banned(&self, address: &SocketAddr) -> bool
Returns whether the given address is banned.
Sourcepub async fn is_permanent(&self, address: &SocketAddr) -> bool
pub async fn is_permanent(&self, address: &SocketAddr) -> bool
Returns whether the given address is a permanent request.
Sourcepub async fn ip_has_permanent_connection(&self, ip: IpAddr) -> bool
pub async fn ip_has_permanent_connection(&self, ip: IpAddr) -> bool
Returns whether the given IP has some permanent request.